==> mx-cleanup_25.5.01.tar.xz: BUILD/translations/mx-cleanup_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>MX Cleanup</source>
        <translation>MX Cleanup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="666"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Main</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>Tools</source>
        <translation>Verktyg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Removal Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Empty Trash</source>
        <translation>Töm Trash</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Trash older than:</source>
        <translation>Trash äldre än:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.ui" line="489"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> days</source>
        <translation>dagar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All users</source>
        <translation>Alla användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>Selected user</source>
        <translation>Vald användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>Clear APT Cache</source>
        <translation>Töm APT cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>Old files</source>
        <translation>Gamla filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="585"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Grafiskt verktyg för att analysera Diskanvändning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="597"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Kör analys av Diskanvändning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Schedule</source>
        <translation>Schema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>No automatic clean</source>
        <translation>Ingen automatisk rensning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>At reboot</source>
        <translation>Vid omstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Daily</source>
        <translation>Dagligen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Weekly</source>
        <translation>Varje vecka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Monthly</source>
        <translation>Varje månad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Free Disk Space for User</source>
        <translation>Ledigt hårddiskutrymme för användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Select user to repair</source>
        <translation>Välj användare att reparera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Select user:</source>
        <translation>Välj användare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Delete Logs</source>
        <translation>Ta bort loggar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>All logs</source>
        <translation>Alla loggar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Old logs</source>
        <translation>Gamla loggar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Logs older than:</source>
        <translation>Loggfiler äldre än:</translation>
    </message>
    <message>
        <source>Removal tool</source>
        <translation type="vanished">Borttagningsverktyg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Ta bort oanvända WiFi drivrutiner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="550"/>
        <source>List and select kernels to remove</source>
        <translation>Lista och välj kärnor att ta bort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Clean Flatpak</source>
        <translation>Rensa Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Remove unused runtimes</source>
        <translation>Ta bort oanvända runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Clean Folders</source>
        <translation>Kataloger att rensa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Not accessed for:</source>
        <translation>Inte använd på:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>All (potentially dangerous)</source>
        <translation>Allt (kan vara farligt)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Thumbnails</source>
        <translation>Minibilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Press any key to close</source>
        <translation>Tryck på valfri tangent för att stänga</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> day</source>
        <translation>dag</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to elevate privileges</source>
        <translation>Misslyckades med att utöka rättigheter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Cleanup script will run at reboot</source>
        <translation>Cleanup skript kommer att köras vid omstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Cleanup command done</source>
        <translation>Cleanup kommando färdigt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB blev frigjort</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Quick and safe removal of old files</source>
        <translation>Snabb och säker borttagning av gamla filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kärna som nu används: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Remove selected</source>
        <translation>Ta bort markerade</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Liknande kärnor som kan tas bort:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <source>Other kernels that can be removed:</source>
        <translation>Andra kärnor som kan tas bort:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Inget att ta bort.&lt;/b&gt; Kan inte ta bort kärna som används.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Snabb och säker borttagning av gamla filer</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
</context>
</TS>

==> mx-cleanup_25.6.03.tar.xz: BUILD/translations/mx-cleanup_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>MX Cleanup</source>
        <translation>MX Cleanup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="658"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Main</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Purge residual configurations from removed packages</source>
        <translation>Ta bort kvarlämnade inställningar från borttagna paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>Tools</source>
        <translation>Verktyg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="545"/>
        <source>Removal Tools</source>
        <translation>Borttagningsverktyg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="583"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Ta bort MX manualer för andra språk än systemstandard</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="781"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="784"/>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="756"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Empty Trash</source>
        <translation>Töm Trash</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="45"/>
        <source>Trash older than:</source>
        <translation>Trash äldre än:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <location filename="../mainwindow.ui" line="294"/>
        <location filename="../mainwindow.ui" line="438"/>
        <location filename="../mainwindow.cpp" line="477"/>
        <source> days</source>
        <translation>dagar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>All users</source>
        <translation>Alla användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Selected user</source>
        <translation>Vald användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Clear APT Cache</source>
        <translation>Töm APT cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Old files</source>
        <translation>Gamla filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Grafiskt verktyg för att analysera Diskanvändning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Kör analys av Diskanvändning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Schedule</source>
        <translation>Schema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>No automatic clean</source>
        <translation>Ingen automatisk rensning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>At reboot</source>
        <translation>Vid omstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Daily</source>
        <translation>Dagligen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Weekly</source>
        <translation>Varje vecka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Monthly</source>
        <translation>Varje månad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>Free Disk Space for User</source>
        <translation>Ledigt hårddiskutrymme för användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.ui" line="495"/>
        <source>Select user to repair</source>
        <translation>Välj användare att reparera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Select user:</source>
        <translation>Välj användare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Delete Logs</source>
        <translation>Ta bort loggar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <source>All logs</source>
        <translation>Alla loggar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Old logs</source>
        <translation>Gamla loggar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Logs older than:</source>
        <translation>Loggfiler äldre än:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Ta bort oanvända WiFi drivrutiner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>List and select kernels to remove</source>
        <translation>Lista och välj kärnor att ta bort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Clean Flatpak</source>
        <translation>Rensa Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <source>Remove unused runtimes</source>
        <translation>Ta bort oanvända runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Clean Folders</source>
        <translation>Kataloger att rensa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Not accessed for:</source>
        <translation>Inte använd på:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>All (potentially dangerous)</source>
        <translation>Allt (kan vara farligt)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <source>Thumbnails</source>
        <translation>Minibilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation>Ta bort Manualer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation>Inga manualer att ta bort.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation>Tar bort paket, var vänlig vänta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <location filename="../mainwindow.cpp" line="823"/>
        <source>Press any key to close</source>
        <translation>Tryck på valfri tangent för att stänga</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source> day</source>
        <translation>dag</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Failed to elevate privileges</source>
        <translation>Misslyckades med att utöka rättigheter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>Cleanup script will run at reboot</source>
        <translation>Cleanup skript kommer att köras vid omstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Cleanup command done</source>
        <translation>Cleanup kommando färdigt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB blev frigjort</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="685"/>
        <source>Quick and safe removal of old files</source>
        <translation>Snabb och säker borttagning av gamla filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="778"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kärna som nu används: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Remove selected</source>
        <translation>Ta bort markerade</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Liknande kärnor som kan tas bort:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="787"/>
        <source>Other kernels that can be removed:</source>
        <translation>Andra kärnor som kan tas bort:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="790"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Inget att ta bort.&lt;/b&gt; Kan inte ta bort kärna som används.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Snabb och säker borttagning av gamla filer</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
</context>
</TS>
